<?php

declare(strict_types=1);

namespace Drupal\secure_nodes\Plugin\Action;

use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Action\Attribute\Action;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Provides a Protect Nodes action.
 *
 * @DCG
 * For updating entity fields consider extending FieldUpdateActionBase.
 * @see \Drupal\Core\Field\FieldUpdateActionBase
 *
 * @DCG
 * In order to set up the action through admin interface the plugin has to be
 * configurable.
 * @see https://www.drupal.org/project/drupal/issues/2815301
 * @see https://www.drupal.org/project/drupal/issues/2815297
 *
 * @DCG
 * The whole action API is subject of change.
 * @see https://www.drupal.org/project/drupal/issues/2011038
 */
#[Action(
  id: 'protect_nodes',
  label: new TranslatableMarkup('Protect Nodes'),
  category: new TranslatableMarkup('Custom'),
  type: 'node',
)]
class ProtectNodes extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function access($entity, AccountInterface $account = NULL, $return_as_object = FALSE): AccessResultInterface|bool {
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $access = $entity->access('update', $account, TRUE)
      ->andIf($entity->get('body')->access('edit', $account, TRUE));
    return $return_as_object ? $access : $access->isAllowed();
  }

  /**
   * {@inheritdoc}
   */
  public function execute(ContentEntityInterface $entity = NULL): void {

    $current_node_type = $entity->getType();
    $protect_config = \Drupal::config('secure_nodes.settings');
    $allowed_types = $protect_config->get('allowed_types');
    if (in_array($current_node_type, $allowed_types)) {
      $enabler = \Drupal::service('secure_nodes.enabler');
      $enabler->setEnabled($entity);
    }

  }

}
